@@ -21,19 +21,20 @@
 #include "magnettest.h"
 
 #include <QApplication>
+#include <QFile>
+#include <QNetworkInterface>
+#include <QTimer>
+
 #include <dht/dhtbase.h>
 #include <magnet/magnetlink.h>
 #include <torrent/globals.h>
 #include <interfaces/functions.h>
 #include <settings.h>
 #include <upnp/upnpmcastsocket.h>
-#include <QTimer>
-#include <QNetworkInterface>
 #include <util/functions.h>
 #include <util/log.h>
 #include <util/error.h>
 #include <torrent/server.h>
-#include <QFile>
 #include <bcodec/bencoder.h>
 #include <peer/authenticationmonitor.h>
 
@@ -44,14 +45,13 @@ using namespace bt;
 MagnetTest::MagnetTest(const bt::MagnetLink& mlink, QObject* parent) : QObject(parent), mlink(mlink)
 {
     upnp = new bt::UPnPMCastSocket();
-    connect(upnp, SIGNAL(discovered(bt::UPnPRouter*)), this, SLOT(routerDiscovered(bt::UPnPRouter*)));
+    connect(upnp, &bt::UPnPMCastSocket::discovered, this, &MagnetTest::routerDiscovered);
 
     mdownloader = new MagnetDownloader(mlink, this);
-    connect(mdownloader, SIGNAL(foundMetaData(bt::MagnetDownloader*, QByteArray)),
-            this, SLOT(foundMetaData(bt::MagnetDownloader*, QByteArray)));
+    connect(mdownloader, &MagnetDownloader::foundMetadata, this, &MagnetTest::foundMetaData);
 
-    QTimer::singleShot(0, this, SLOT(start()));
-    connect(&timer, SIGNAL(timeout()), this, SLOT(update()));
+    QTimer::singleShot(0, this, &MagnetTest::start);
+    connect(&timer, &QTimer::timeout, this, &MagnetTest::update);
 }
 
 MagnetTest::~MagnetTest()
@@ -101,10 +101,10 @@ void MagnetTest::start()
     }
 
     // start DHT
-    bt::Globals::instance().getDHT().start(kt::DataDir() + "dht_table", kt::DataDir() + "dht_key", Settings::dhtPort());
+    bt::Globals::instance().getDHT().start(kt::DataDir() + QStringLiteral("dht_table"), kt::DataDir() + QStringLiteral("dht_key"), Settings::dhtPort());
 
     // Start UPnP router discovery
-    upnp->loadRouters(kt::DataDir() + "routers");
+    upnp->loadRouters(kt::DataDir() + QStringLiteral("routers"));
     upnp->discover();
 
     mdownloader->start();
@@ -130,30 +130,30 @@ void MagnetTest::foundMetaData(MagnetDownloader* md, const QByteArray& data)
     Q_UNUSED(md);
     Out(SYS_GEN | LOG_IMPORTANT) << "Saving to output.torrent" << endl;
     bt::File fptr;
-    if (fptr.open("output.torrent", "wb"))
+    if (fptr.open(QStringLiteral("output.torrent"), QStringLiteral("wb")))
     {
         BEncoder enc(&fptr);
         enc.beginDict();
-        Qlist<QUrl> trs = mlink.trackers();
+        QList<QUrl> trs = mlink.trackers();
         if (trs.count())
         {
-            enc.write("announce");
-            enc.write(trs.first().prettyUrl());
+            enc.write(QByteArrayLiteral("announce"));
+            enc.write(trs.first().toEncoded());
             if (trs.count() > 1)
             {
-                enc.write("announce-list");
+                enc.write(QByteArrayLiteral("announce-list"));
                 enc.beginList();
-                foreach (const QUrl& u, trs)
+                for (const QUrl& u : qAsConst(trs))
                 {
-                    enc.write(u.toDisplayString());
+                    enc.write(u.toEncoded());
                 }
                 enc.end();
             }
         }
-        enc.write("info");
+        enc.write(QByteArrayLiteral("info"));
         fptr.write(data.data(), data.size());
         enc.end();
-        QTimer::singleShot(0, qApp, SLOT(quit()));
+        QTimer::singleShot(0, qApp, &QCoreApplication::quit);
     }
     else
     {
