@@ -17,10 +17,13 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include <QHeaderView>
-#include <QSortFilterProxyModel>
 #include <QPushButton>
-#include <klocalizedstring.h>
+#include <QSortFilterProxyModel>
+
+#include <KLocalizedString>
+
 #include <util/constants.h>
 #include <util/log.h>
 #include <interfaces/functions.h>
@@ -42,11 +45,10 @@ namespace kt
 
 
     SpeedLimitsDlg::SpeedLimitsDlg(bt::TorrentInterface* current, Core* core, QWidget* parent)
-        : KDialog(parent), core(core), current(current)
+        : QDialog(parent), core(core), current(current)
     {
-        setButtons(KDialog::Ok | KDialog::Apply | KDialog::Cancel);
-        setupUi(mainWidget());
-        setWindowIcon(QIcon::fromTheme("kt-speed-limits"));
+        setupUi(this);
+        setWindowIcon(QIcon::fromTheme(QStringLiteral("kt-speed-limits")));
         setWindowTitle(i18n("Speed Limits"));
 
         model = new SpeedLimitsModel(core, this);
@@ -60,20 +62,21 @@ namespace kt
         m_speed_limits_view->setSortingEnabled(true);
         m_speed_limits_view->sortByColumn(0, Qt::AscendingOrder);
         m_speed_limits_view->header()->setSortIndicatorShown(true);
-        m_speed_limits_view->header()->setClickable(true);
+        m_speed_limits_view->header()->setSectionsClickable(true);
         m_speed_limits_view->setAlternatingRowColors(true);
 
-        connect(this, SIGNAL(applyClicked()), this, SLOT(apply()));
-
-        QPushButton* apply_btn = button(KDialog::Apply);
+        QPushButton* apply_btn = m_buttonBox->button(QDialogButtonBox::Apply);
         apply_btn->setEnabled(false);
-        connect(model, SIGNAL(enableApply(bool)), apply_btn, SLOT(setEnabled(bool)));
+        connect(model, &SpeedLimitsModel::enableApply, apply_btn, &QPushButton::setEnabled);
+        connect(apply_btn, &QPushButton::clicked, this, &SpeedLimitsDlg::apply);
+        connect(m_buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+        connect(m_buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 
         m_upload_rate->setValue(Settings::maxUploadRate());
         m_download_rate->setValue(Settings::maxDownloadRate());
-        connect(m_upload_rate, SIGNAL(valueChanged(int)), this, SLOT(spinBoxValueChanged(int)));
-        connect(m_download_rate, SIGNAL(valueChanged(int)), this, SLOT(spinBoxValueChanged(int)));
-        connect(m_filter, SIGNAL(textChanged(QString)), pm, SLOT(setFilterFixedString(QString)));
+        connect(m_upload_rate, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SpeedLimitsDlg::spinBoxValueChanged);
+        connect(m_download_rate, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SpeedLimitsDlg::spinBoxValueChanged);
+        connect(m_filter, &QLineEdit::textChanged, pm, &QSortFilterProxyModel::setFilterFixedString);
         loadState();
 
         // if current is specified, select it and scroll to it
@@ -121,7 +124,7 @@ namespace kt
         {
             m_speed_limits_view->header()->restoreState(s);
             m_speed_limits_view->header()->setSortIndicatorShown(true);
-            m_speed_limits_view->header()->setClickable(true);
+            m_speed_limits_view->header()->setSectionsClickable(true);
         }
 
         QSize ws = g.readEntry("size", size());
@@ -144,7 +147,7 @@ namespace kt
     void SpeedLimitsDlg::apply()
     {
         model->apply();
-        button(KDialog::Apply)->setEnabled(false);
+        m_buttonBox->button(QDialogButtonBox::Apply)->setEnabled(false);
 
         bool apply = false;
         if (Settings::maxUploadRate() != m_upload_rate->value())
@@ -168,7 +171,7 @@ namespace kt
 
     void SpeedLimitsDlg::spinBoxValueChanged(int)
     {
-        button(KDialog::Apply)->setEnabled(true);
+        m_buttonBox->button(QDialogButtonBox::Apply)->setEnabled(true);
     }
 
 }
