@@ -37,7 +37,7 @@ namespace kt
         Q_OBJECT
     public:
         GroupFilterModel(ViewModel* view_model, QObject* parent);
-        ~GroupFilterModel();
+        ~GroupFilterModel() override;
 
         bool filterAcceptsColumn(int source_column, const QModelIndex& source_parent) const override;
         bool filterAcceptsRow(int source_row, const QModelIndex& source_parent) const override;
