@@ -42,12 +42,9 @@
 #include <KLocalizedString>
 #include <KStartupInfo>
 #include <KWindowSystem>
+#include <kwindowsystem_version.h>
 
-#include <util/log.h>
 #include <torrent/globals.h>
-#include <util/functions.h>
-#include <util/error.h>
-#include <util/log.h>
 #include <interfaces/functions.h>
 #include <utp/connection.h>
 #include "gui.h"
@@ -55,7 +52,6 @@
 
 #include "version.h"
 #include "ktversion.h"
-#include <torrent/globals.h>
 #include <util/error.h>
 #include <util/log.h>
 #include <util/functions.h>
@@ -112,6 +108,7 @@ int main(int argc, char** argv)
     bt::SetClientInfo(QStringLiteral("KTorrent"), kt::MAJOR, kt::MINOR, kt::RELEASE, kt::VERSION_TYPE, QStringLiteral("KT"));
 
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
+    QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     KLocalizedString::setApplicationDomain("ktorrent");
 
     QApplication app(argc, argv);
@@ -179,9 +176,8 @@ int main(int argc, char** argv)
     about.addCredit(i18n("Nick Shaforostoff"), i18n("KF5 porting"), QStringLiteral("shaforostoff@gmail.com"));
 
     KAboutData::setApplicationData(about);
-    parser.addVersionOption();
-    parser.addHelpOption();
     about.setupCommandLine(&parser);
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("verbose"), i18n("Enable logging to standard output")));
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("silent"), i18n( "Silently open torrent given on URL")));
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("+[URL]"), i18n( "Document to open" )));
     parser.process(app);
@@ -208,7 +204,8 @@ int main(int argc, char** argv)
         QObject::connect(&catcher, &bt::SignalCatcher::triggered, &app, &QApplication::quit);
 #endif
 
-        bt::InitLog(kt::DataDir(kt::CreateIfNotExists) + QLatin1String("log"), true, true, true);
+        const bool logToStdout = parser.isSet(QStringLiteral("verbose"));
+        bt::InitLog(kt::DataDir(kt::CreateIfNotExists) + QLatin1String("log"), true, true, logToStdout);
 
         kt::GUI widget;
         widget.show();
@@ -218,7 +215,12 @@ int main(int argc, char** argv)
             if (!arguments.isEmpty())
             {
                 parser.parse(arguments);
+#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5,62,0)
+                widget.setAttribute(Qt::WA_NativeWindow, true);
+                KStartupInfo::setNewStartupId(widget.windowHandle(), KStartupInfo::startupId());
+#else
                 KStartupInfo::setNewStartupId(&widget, KStartupInfo::startupId());
+#endif
                 KWindowSystem::forceActiveWindow(widget.winId());
             }
             QString oldCurrent = QDir::currentPath();
