@@ -17,14 +17,17 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "viewdelegate.h"
 #include "viewmodel.h"
 #include "core.h"
 #include "view.h"
+
 #include <QApplication>
-#include <QRect>
 #include <QLocale>
+#include <QRect>
 #include <QVBoxLayout>
+
 #include <gui/extender.h>
 
 
@@ -225,23 +228,23 @@ namespace kt
 
     void ViewDelegate::paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const
     {
-        QStyleOptionViewItemV4 indicatorOption(option);
+        QStyleOptionViewItem indicatorOption(option);
         initStyleOption(&indicatorOption, index);
         if (index.column() == 0)
-            indicatorOption.viewItemPosition = QStyleOptionViewItemV4::Beginning;
+            indicatorOption.viewItemPosition = QStyleOptionViewItem::Beginning;
         else if (index.column() == index.model()->columnCount() - 1)
-            indicatorOption.viewItemPosition = QStyleOptionViewItemV4::End;
+            indicatorOption.viewItemPosition = QStyleOptionViewItem::End;
         else
-            indicatorOption.viewItemPosition = QStyleOptionViewItemV4::Middle;
+            indicatorOption.viewItemPosition = QStyleOptionViewItem::Middle;
 
-        QStyleOptionViewItemV4 itemOption(option);
+        QStyleOptionViewItem itemOption(option);
         initStyleOption(&itemOption, index);
         if (index.column() == 0)
-            itemOption.viewItemPosition = QStyleOptionViewItemV4::Beginning;
+            itemOption.viewItemPosition = QStyleOptionViewItem::Beginning;
         else if (index.column() == index.model()->columnCount() - 1)
-            itemOption.viewItemPosition = QStyleOptionViewItemV4::End;
+            itemOption.viewItemPosition = QStyleOptionViewItem::End;
         else
-            itemOption.viewItemPosition = QStyleOptionViewItemV4::Middle;
+            itemOption.viewItemPosition = QStyleOptionViewItem::Middle;
 
 
         bt::TorrentInterface* tc = model->torrentFromIndex(index);
@@ -256,7 +259,7 @@ namespace kt
 
 
         //an extender is present - make two rectangles: one to paint the original item, one for the extender
-        QStyleOptionViewItemV4 extOption(option);
+        QStyleOptionViewItem extOption(option);
         initStyleOption(&extOption, index);
         extOption.rect = extenderRect(extender, option, index);
         extender->setGeometry(extOption.rect);
@@ -286,7 +289,7 @@ namespace kt
             QWidget* extender = extenders[tc];
             int extenderHeight = extender->sizeHint().height();
 
-            QStyleOptionViewItemV4 itemOption(option);
+            QStyleOptionViewItem itemOption(option);
             initStyleOption(&itemOption, index);
             itemOption.rect.setHeight(option.rect.height() - extenderHeight);
             editor->setGeometry(itemOption.rect);
@@ -367,7 +370,7 @@ namespace kt
         progressBarOption.minimum = 0;
         progressBarOption.maximum = 100;
         progressBarOption.progress = progress;
-        progressBarOption.text = QLocale().toString(progress) + '%';
+        progressBarOption.text = QLocale().toString(progress) + QLatin1Char('%');
         progressBarOption.textVisible = true;
         progressBarOption.direction = option.direction;
 
