@@ -18,9 +18,12 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include <QDBusConnection>
 #include <QThread>
-#include <klocalizedstring.h>
+
+#include <KLocalizedString>
+
 #include <util/log.h>
 #include <util/sha1hash.h>
 #include <util/bitset.h>
@@ -47,13 +50,11 @@ namespace kt
         QFlags<QDBusConnection::RegisterOption> flags = QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals;
         sb.registerObject(path, this, flags);
 
-        connect(ti, SIGNAL(finished(bt::TorrentInterface*)), this, SLOT(onFinished(bt::TorrentInterface*)));
-        connect(ti, SIGNAL(stoppedByError(bt::TorrentInterface*, QString)),
-                this, SLOT(onStoppedByError(bt::TorrentInterface*, const QString&)));
-        connect(ti, SIGNAL(seedingAutoStopped(bt::TorrentInterface*, bt::AutoStopReason)),
-                this, SLOT(onSeedingAutoStopped(bt::TorrentInterface*, bt::AutoStopReason)));
-        connect(ti, SIGNAL(corruptedDataFound(bt::TorrentInterface*)), this, SLOT(onCorruptedDataFound(bt::TorrentInterface*)));
-        connect(ti, SIGNAL(torrentStopped(bt::TorrentInterface*)), this, SLOT(onTorrentStopped(bt::TorrentInterface*)));
+        connect(ti, &bt::TorrentInterface::finished, this, &DBusTorrent::onFinished);
+        connect(ti, &bt::TorrentInterface::stoppedByError, this, &DBusTorrent::onStoppedByError);
+        connect(ti, &bt::TorrentInterface::seedingAutoStopped, this, &DBusTorrent::onSeedingAutoStopped);
+        connect(ti, &bt::TorrentInterface::corruptedDataFound, this, &DBusTorrent::onCorruptedDataFound);
+        connect(ti, &bt::TorrentInterface::torrentStopped, this, &DBusTorrent::onTorrentStopped);
     }
 
 
@@ -160,9 +161,9 @@ namespace kt
 
     QStringList DBusTorrent::trackers() const
     {
-        QList<bt::TrackerInterface*> trackers = ti->getTrackersList()->getTrackers();
+        const QList<bt::TrackerInterface*> trackers = ti->getTrackersList()->getTrackers();
         QStringList ret;
-        foreach (bt::TrackerInterface* t, trackers)
+        for (bt::TrackerInterface* t : trackers)
             ret << t->trackerURL().toDisplayString();
         return ret;
     }
