@@ -18,9 +18,9 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-
 #include "dbustorrentfilestream.h"
 #include "dbustorrent.h"
+
 #include <QDBusConnection>
 #include <util/sha1hash.h>
 
@@ -30,7 +30,7 @@ namespace kt
     DBusTorrentFileStream::DBusTorrentFileStream(bt::Uint32 file_index, kt::DBusTorrent* tor) : QObject(tor), tor(tor)
     {
         QDBusConnection sb = QDBusConnection::sessionBus();
-        QString path = QString("/torrent/%1/stream").arg(tor->torrent()->getInfoHash().toString());
+        QString path = QStringLiteral("/torrent/%1/stream").arg(tor->torrent()->getInfoHash().toString());
         QFlags<QDBusConnection::RegisterOption> flags = QDBusConnection::ExportScriptableSlots | QDBusConnection::ExportScriptableSignals;
         sb.registerObject(path, this, flags);
 
