@@ -39,7 +39,7 @@ namespace kt
         Q_OBJECT
     public:
         MediaFileStream(bt::TorrentFileStream::WPtr stream, QObject* parent = 0);
-        ~MediaFileStream();
+        ~MediaFileStream() override;
 
         enum StreamState
         {
