@@ -17,17 +17,22 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
+
 #include "searchactivity.h"
 
+#include <algorithm>
+
 #include <QFile>
-#include <QTextStream>
-#include <QVBoxLayout>
-#include <QToolButton>
-#include <klocalizedstring.h>
 #include <QIcon>
-#include <KConfigGroup>
-#include <KStandardAction>
+#include <QTextStream>
+#include <QToolButton>
+#include <QVBoxLayout>
+
 #include <KActionCollection>
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KStandardAction>
+
 #include <interfaces/functions.h>
 #include <util/indexofcompare.h>
 #include <util/error.h>
@@ -44,13 +49,12 @@
 namespace kt
 {
     SearchActivity::SearchActivity(SearchPlugin* sp, QWidget* parent)
-        : Activity(i18nc("plugin name", "Search"), QLatin1String("edit-find"), 10, parent), sp(sp)
+        : Activity(i18nc("plugin name", "Search"), QStringLiteral("edit-find"), 10, parent), sp(sp)
     {
         setXMLGUIFile(QStringLiteral("ktorrent_searchui.rc"));
         setupActions();
         toolbar = new SearchToolBar(part()->actionCollection(), sp->getSearchEngineList(), this);
-        connect(toolbar, SIGNAL(search(const QString&, int, bool)),
-                sp, SLOT(search(const QString&, int, bool)));
+        connect(toolbar, &SearchToolBar::search, sp, &SearchPlugin::search);
 
         QVBoxLayout* layout = new QVBoxLayout(this);
         layout->setSpacing(0);
@@ -58,16 +62,16 @@ namespace kt
         tabs = new QTabWidget(this);
         tabs->setMovable(true);
         layout->addWidget(tabs);
-        connect(tabs, SIGNAL(currentChanged(int)), this, SLOT(currentTabChanged(int)));
+        connect(tabs, &QTabWidget::currentChanged, this, &SearchActivity::currentTabChanged);
 
         QToolButton* lc = new QToolButton(tabs);
         tabs->setCornerWidget(lc, Qt::TopLeftCorner);
         QToolButton* rc = new QToolButton(tabs);
         tabs->setCornerWidget(rc, Qt::TopRightCorner);
         lc->setIcon(QIcon::fromTheme(QStringLiteral("tab-new")));
-        connect(lc, SIGNAL(clicked()), this, SLOT(openTab()));
+        connect(lc, &QToolButton::clicked, this, &SearchActivity::openTab);
         rc->setIcon(QIcon::fromTheme(QStringLiteral("tab-close")));
-        connect(rc, SIGNAL(clicked()), this, SLOT(closeTab()));
+        connect(rc, &QToolButton::clicked, this, &SearchActivity::closeTab);
     }
 
     SearchActivity::~SearchActivity()
@@ -79,7 +83,7 @@ namespace kt
         KActionCollection* ac = part()->actionCollection();
 
         search_action = new QAction(QIcon::fromTheme(QStringLiteral("edit-find")), i18n("Search"), this);
-        connect(search_action, SIGNAL(triggered()), this, SLOT(search()));
+        connect(search_action, &QAction::triggered, this, static_cast<void (SearchActivity::*)()>(&SearchActivity::search));
         ac->addAction(QStringLiteral("search_tab_search"), search_action);
 
         find_action = KStandardAction::find(this, SLOT(find()), this);
@@ -91,9 +95,9 @@ namespace kt
 
     void SearchActivity::search(const QString& text, int engine)
     {
-        foreach (SearchWidget* s, searches)
+        for (SearchWidget* s : qAsConst(searches))
         {
-            if (s->getCurrentUrl() == QUrl(QLatin1String("about:ktorrent")))
+            if (s->getCurrentUrl() == QUrl(QStringLiteral("about:ktorrent")))
             {
                 s->search(text, engine);
                 tabs->setCurrentWidget(s);
@@ -108,20 +112,20 @@ namespace kt
 
     void SearchActivity::saveCurrentSearches()
     {
-        QFile fptr(kt::DataDir() + QLatin1String("current_searches"));
+        QFile fptr(kt::DataDir() + QStringLiteral("current_searches"));
         if (!fptr.open(QIODevice::WriteOnly))
             return;
 
         // Sort by order in tab widget so that they are restored in the proper order
-        qSort(searches.begin(), searches.end(), IndexOfCompare<QTabWidget, SearchWidget>(tabs));
+        std::sort(searches.begin(), searches.end(), IndexOfCompare<QTabWidget, SearchWidget>(tabs));
         bt::BEncoder enc(&fptr);
         enc.beginList();
-        foreach (SearchWidget* w, searches)
+        for (SearchWidget* w : qAsConst(searches))
         {
             enc.beginDict();
-            enc.write("TEXT", w->getSearchText());
-            enc.write("URL", w->getCurrentUrl().toDisplayString());
-            enc.write("SBTEXT", w->getSearchBarText());
+            enc.write("TEXT", w->getSearchText().toUtf8());
+            enc.write("URL", w->getCurrentUrl().toDisplayString().toUtf8());
+            enc.write("SBTEXT", w->getSearchBarText().toUtf8());
             enc.write("ENGINE", (bt::Uint32)w->getSearchBarEngine());
             enc.end();
         }
@@ -152,7 +156,7 @@ namespace kt
         {
             search_list = dec.decodeList();
             if (!search_list)
-                throw bt::Error("Invalid current searches");
+                throw bt::Error(QStringLiteral("Invalid current searches"));
 
             for (bt::Uint32 i = 0; i < search_list->getNumChildren(); i++)
             {
@@ -245,9 +249,9 @@ namespace kt
         if (!text.isEmpty())
             tabs->setTabToolTip(idx, i18n("Search for %1", text));
 
-        connect(search, SIGNAL(openNewTab(const QUrl&)), this, SLOT(openNewTab(const QUrl&)));
-        connect(search, SIGNAL(changeTitle(SearchWidget*, QString)), this, SLOT(setTabTitle(SearchWidget*, QString)));
-        connect(search, SIGNAL(changeIcon(SearchWidget*, QIcon)), this, SLOT(setTabIcon(SearchWidget*, QIcon)));
+        connect(search, &SearchWidget::openNewTab, this, &SearchActivity::openNewTab);
+        connect(search, &SearchWidget::changeTitle, this, &SearchActivity::setTabTitle);
+        connect(search, &SearchWidget::changeIcon, this, &SearchActivity::setTabIcon);
         searches.append(search);
         search->setSearchBarEngine(toolbar->currentSearchEngine());
         return search;
