@@ -122,7 +122,7 @@ class KCfgFile:
 		if kcfg_type in self.type_map:
 			return self.type_map[kcfg_type]
 		else:
-			raise "Unkown type %s" % (kcfg_type)
+			raise "Unknown type %s" % (kcfg_type)
 			
 	def writeDeclarations(self,indent,output):
 		for entry in self.entries:
@@ -237,4 +237,4 @@ def main(args):
 
 if __name__ == "__main__":
 	main(sys.argv[1:])
-	exit(0)
\ No newline at end of file
+	exit(0)
